.. _building_blocks:

================================================
Advanced usage: manual pipelines and scaling up
================================================

In this section of the nilearn documentation, we describe the building
blocks that can be assembled to create a machine-learning data analysis
pipeline. This section is slightly more advanced and abstract than the
other. It provides knowledge that is useful to go off the beaten path in
terms of data processing.

.. toctree::

   manual_pipeline.rst
   neurovault.rst
